summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/kopetechatwindowstyle.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/kopete/chatwindow/kopetechatwindowstyle.h')
-rw-r--r--kopete/kopete/chatwindow/kopetechatwindowstyle.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kopete/kopete/chatwindow/kopetechatwindowstyle.h b/kopete/kopete/chatwindow/kopetechatwindowstyle.h
index ca5a0863..43c54887 100644
--- a/kopete/kopete/chatwindow/kopetechatwindowstyle.h
+++ b/kopete/kopete/chatwindow/kopetechatwindowstyle.h
@@ -17,8 +17,8 @@
#ifndef KOPETECHATWINDOWSTYLE_H
#define KOPETECHATWINDOWSTYLE_H
-#include <qstring.h>
-#include <qmap.h>
+#include <tqstring.h>
+#include <tqmap.h>
/**
@@ -35,7 +35,7 @@ public:
* value = Path to variant CSS file.
* Path is relative to Ressources directory.
*/
- typedef QMap<QString,QString> StyleVariants;
+ typedef TQMap<TQString,TQString> StyleVariants;
/**
* This enum specifies the mode of the constructor
@@ -48,8 +48,8 @@ public:
* @brief Build a single chat window style.
*
*/
- ChatWindowStyle(const QString &stylePath, int styleBuildMode = StyleBuildNormal);
- ChatWindowStyle(const QString &stylePath, const QString &variantPath, int styleBuildMode = StyleBuildFast);
+ ChatWindowStyle(const TQString &stylePath, int styleBuildMode = StyleBuildNormal);
+ ChatWindowStyle(const TQString &stylePath, const TQString &variantPath, int styleBuildMode = StyleBuildFast);
~ChatWindowStyle();
/**
@@ -58,7 +58,7 @@ public:
* before returning the list of the Variants.
* If the variant are listed, it just return the cached
* variant list.
* @return the StyleVariants QMap.
*/
StyleVariants getVariants();
@@ -69,7 +69,7 @@ public:
*
* @return the style path based.
*/
- QString getStylePath() const;
+ TQString getStylePath() const;
/**
* Get the style ressource directory.
@@ -82,18 +82,18 @@ public:
*
* @return the path to the the ressource directory.
*/
- QString getStyleBaseHref() const;
+ TQString getStyleBaseHref() const;
- QString getHeaderHtml() const;
- QString getFooterHtml() const;
- QString getIncomingHtml() const;
- QString getNextIncomingHtml() const;
- QString getOutgoingHtml() const;
- QString getNextOutgoingHtml() const;
- QString getStatusHtml() const;
+ TQString getHeaderHtml() const;
+ TQString getFooterHtml() const;
+ TQString getIncomingHtml() const;
+ TQString getNextIncomingHtml() const;
+ TQString getOutgoingHtml() const;
+ TQString getNextOutgoingHtml() const;
+ TQString getStatusHtml() const;
- QString getActionIncomingHtml() const;
- QString getActionOutgoingHtml() const;
+ TQString getActionIncomingHtml() const;
+ TQString getActionOutgoingHtml() const;
/**
* Check if the style has the support for Kopete Action template (Kopete extension)
@@ -114,7 +114,7 @@ private:
/**
* Init this class
*/
- void init(const QString &stylePath, int styleBuildMode);
+ void init(const TQString &stylePath, int styleBuildMode);
/**
* List available variants for the current style.
@@ -58,7 +58,7 @@ public:
* If the variant are listed, it just return the cached
* variant list.
- * @return the StyleVariants QMap.
+ * @return the StyleVariants TQMap.
*/
StyleVariants getVariants();